==> haskell-tls-session-manager-0.0.0.2-87-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tls-session-manager
version: 0.0.0.2
id: tls-session-manager-0.0.0.2-CUd3BGTWfC2EkXlk7GyAAw
key: tls-session-manager-0.0.0.2-CUd3BGTWfC2EkXlk7GyAAw
license: BSD-3-Clause
maintainer: kazu@iij.ad.jp
author: Kazu Yamamoto
synopsis: In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance
category: Web
abi: 7523c1115a8f61d05b383c5a74e4f71b
exposed: True
exposed-modules:
    Network.TLS.SessionManager
hidden-modules: Network.TLS.Imports
import-dirs: /usr/lib/ghc-8.6.3/site-local/tls-session-manager-0.0.0.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/tls-session-manager-0.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/tls-session-manager-0.0.0.2
hs-libraries: HStls-session-manager-0.0.0.2-CUd3BGTWfC2EkXlk7GyAAw
depends:
    auto-update-0.1.4.1-H02SxzDXmGPGYG55qTZ7dl base-4.12.0.0
    clock-0.7.2-DpdvDKMysiO5fhuByT1Vyj
    psqueues-0.2.7.1-D4OOvYFG3LaJSXfYcKR0P
    tls-1.4.1-26L9gg1we2wDG3y0Ffxu9I
haddock-interfaces: /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock
haddock-html: /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tls-session-manager-0.0.0.2-88-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tls-session-manager
version: 0.0.0.2
id: tls-session-manager-0.0.0.2-8FIaJThkerR9ITc7KkFwmT
key: tls-session-manager-0.0.0.2-8FIaJThkerR9ITc7KkFwmT
license: BSD-3-Clause
maintainer: kazu@iij.ad.jp
author: Kazu Yamamoto
synopsis: In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance
category: Web
abi: c45c7f8fc3cb62f3765caa2fd4169b90
exposed: True
exposed-modules:
    Network.TLS.SessionManager
hidden-modules: Network.TLS.Imports
import-dirs: /usr/lib/ghc-8.6.4/site-local/tls-session-manager-0.0.0.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/tls-session-manager-0.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/tls-session-manager-0.0.0.2
hs-libraries: HStls-session-manager-0.0.0.2-8FIaJThkerR9ITc7KkFwmT
depends:
    auto-update-0.1.4.1-H02SxzDXmGPGYG55qTZ7dl base-4.12.0.0
    clock-0.7.2-DpdvDKMysiO5fhuByT1Vyj
    psqueues-0.2.7.1-KK5603rYUYa6x1F4YO1Gd3
    tls-1.4.1-1yogGf8TCArFPG6nltRb1b
haddock-interfaces: /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock
haddock-html: /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
